@@ -169,6 +169,19 @@ is therefore irrelevant.
 EOF
 }
 
+$q = &prompt(<<"EOF", "n", 0);
+Bucktooth does not explicitly enable your (x)inetd/launchd to listen for IPv6
+connections, though some will do this automatically. If you have IPv6
+connectivity and expect connections over IPv6, you can enable an experimental
+compatibility mode to help with reverse resolution. THIS SUPPORT IS
+EXPERIMENTAL. If you don't know what to do, or expect primarily to use IPv4,
+you should answer no.
+
+Enable EXPERIMENTAL IPv6 support?
+EOF
+
+$DEF_MIPV6 = (($q eq 'y') ? 1 : 0);
+
 if ($DEF_MCANALARM) {
 	$q = &prompt(<<"EOF", "n", 1);
 Now the ugly kludge section. This is really only relevant to inetd users, but
@@ -238,6 +251,9 @@ wildcards), the old behaviour is still used, and if NO files match, NOTHING is
 displayed. In all other types of gophermap entries, the glob is not expanded
 and is left literal.
 
+If you enable gopher tags, if a matched file is a directory and has a tag,
+the tag is used for the display string automatically (we'll get to that).
+
 Read the manual for all the details, including notes on glob() in older Perls.
 This is unlikely to break most gophermaps, so this is the default. However, if
 you DO have files with wildcards in their names, this WILL break them then!
@@ -277,6 +293,19 @@ to keep maintaining links the old way as individual resources, then select no.
 Enable smart linking?
 EOF
 
+$DEF_MGOPHERTAGS = (&prompt(<<"EOF", "y", 1) eq 'y') ? 1 : 0;
+It can be difficult to keep menu titles in sync, especially when you have a
+lot of menus pointing to other menus. In 0.2.8 and up, if you put a line of
+text in a file named 'gophertag' in a directory, then if you don't specify a
+display string (e.g., 1..<TAB>), the tag is used. This makes gophermaps smaller
+and causes less headaches.
+
+This option defaults to yes. Say no if you actually have files named
+'gophertag'.
+
+Enable gopher tagging?
+EOF
+
 $DEF_MEXEC_EXT = (&prompt(<<"EOF", "n", 1) eq 'y') ? 1 : 0;
 On certain impoverished filesystems, or places where your umask is weird,
 you might not have full control over your execute bits (Cygwin comes to mind)
